import { computed, defineComponent, openBlock, createBlock, withModifiers, withScopeId, resolveDynamicComponent, createTextVNode, toDisplayString } from 'vue';
import { mapValues, without, pick } from 'lodash-es';

// the common default props, all the components should have these props
const commonDefaultProps = {
    // actions
    actionType: '',
    url: '',
    // size
    height: '',
    width: '318px',
    paddingLeft: '0px',
    paddingRight: '0px',
    paddingTop: '0px',
    paddingBottom: '0px',
    // border type
    borderStyle: 'none',
    borderColor: '#000',
    borderWidth: '0',
    borderRadius: '0',
    // shadow and opacity
    boxShadow: '0 0 0 #000000',
    opacity: 1,
    // position and x,y
    position: 'absolute',
    left: '0',
    top: '0',
    right: '0'
};
const textDefaultProps = {
    // basic props - font styles
    text: '正文内容',
    fontSize: '14px',
    fontFamily: '',
    fontWeight: 'normal',
    fontStyle: 'normal',
    textDecoration: 'none',
    lineHeight: '1',
    textAlign: 'left',
    color: '#000000',
    backgroundColor: '',
    ...commonDefaultProps
};
const imageDefaultProps = {
    imageSrc: '',
    ...commonDefaultProps
};
const shapeDefaultProps = {
    backgroundColor: '',
    ...commonDefaultProps
};
// this contains all default props for all the components
// useful for inserting new component into the store
const componentsDefaultProps = {
    'l-text': {
        props: textDefaultProps
    },
    'l-image': {
        props: imageDefaultProps
    },
    'l-shape': {
        props: shapeDefaultProps
    }
};
const isEditingProp = {
    isEditing: {
        type: Boolean,
        default: false
    }
};
const transformToComponentProps = (props, extraProps) => {
    const mapProps = mapValues(props, (item) => {
        return {
            type: item.constructor,
            default: item
        };
    });
    if (extraProps) {
        return { ...mapProps, ...extraProps };
    }
    else {
        return mapProps;
    }
};

const useComponentClick = (props) => {
    const handleClick = () => {
        if (props.actionType && props.url && !props.isEditing) {
            window.location.href = props.url;
        }
    };
    return handleClick;
};

const defaultStyles = without(Object.keys(textDefaultProps), 'actionType', 'url', 'text');
const useStylePick = (props, pickStyles = defaultStyles) => {
    return computed(() => pick(props, pickStyles));
};

const defaultProps$2 = transformToComponentProps(componentsDefaultProps["l-image"].props, isEditingProp);
var script$2 = defineComponent({
    name: "l-image",
    props: {
        ...defaultProps$2,
    },
    setup(props) {
        const styleProps = useStylePick(props);
        const handleClick = useComponentClick(props);
        return {
            styleProps,
            handleClick,
        };
    },
});

const _withId$1 = /*#__PURE__*/withScopeId("data-v-1e970aa2");

const render$2 = /*#__PURE__*/_withId$1((_ctx, _cache, $props, $setup, $data, $options) => {
  return (openBlock(), createBlock("img", {
    style: _ctx.styleProps,
    class: "l-image-component",
    src: _ctx.imageSrc,
    onClick: _cache[1] || (_cache[1] = withModifiers((...args) => (_ctx.handleClick && _ctx.handleClick(...args)), ["prevent"])),
    draggable: false
  }, null, 12 /* STYLE, PROPS */, ["src"]))
});

script$2.render = render$2;
script$2.__scopeId = "data-v-1e970aa2";
script$2.__file = "src/components/LImage/LImage.vue";

script$2.install = (app) => {
    app.component(script$2.name, script$2);
};

const extraProps = {
    tag: {
        type: String,
        default: "p",
    },
    ...isEditingProp,
};
const defaultProps$1 = transformToComponentProps(componentsDefaultProps["l-text"].props, extraProps);
var script$1 = defineComponent({
    name: "l-text",
    props: {
        ...defaultProps$1,
    },
    setup(props) {
        const styleProps = useStylePick(props);
        const handleClick = useComponentClick(props);
        return {
            styleProps,
            handleClick,
        };
    },
});

const _withId = /*#__PURE__*/withScopeId("data-v-6bf95b7a");

const render$1 = /*#__PURE__*/_withId((_ctx, _cache, $props, $setup, $data, $options) => {
  return (openBlock(), createBlock(resolveDynamicComponent(_ctx.tag), {
    style: _ctx.styleProps,
    class: "l-text-component",
    onClick: _ctx.handleClick
  }, {
    default: _withId(() => [
      createTextVNode(toDisplayString(_ctx.text), 1 /* TEXT */)
    ]),
    _: 1 /* STABLE */
  }, 8 /* PROPS */, ["style", "onClick"]))
});

script$1.render = render$1;
script$1.__scopeId = "data-v-6bf95b7a";
script$1.__file = "src/components/LText/LText.vue";

script$1.install = (app) => {
    app.component(script$1.name, script$1);
};

const defaultProps = transformToComponentProps(componentsDefaultProps["l-shape"].props, isEditingProp);
// array that contains style props
var script = defineComponent({
    name: "l-shape",
    props: {
        ...defaultProps,
    },
    setup(props) {
        const styleProps = useStylePick(props);
        const handleClick = useComponentClick(props);
        return {
            styleProps,
            handleClick,
        };
    },
});

function render(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createBlock("div", {
    onClick: _cache[1] || (_cache[1] = withModifiers((...args) => (_ctx.handleClick && _ctx.handleClick(...args)), ["prevent"])),
    style: _ctx.styleProps,
    class: "l-shape-component",
    draggable: false
  }, null, 4 /* STYLE */))
}

script.render = render;
script.__file = "src/components/LShape/LShape.vue";

script.install = (app) => {
    app.component(script.name, script);
};

const components = [
    script$2,
    script$1,
    script
];
const install = (app) => {
    components.forEach(component => {
        app.component(component.name, component);
    });
};
var index = {
    install
};

export { script$2 as LImage, script as LShape, script$1 as LText, index as default, install };
